import 'dart:math';

import 'package:flutter/material.dart';

import '../../../flutter_chat_ui_kit.dart';

class LiveReactionAnimation extends StatefulWidget {
  final VoidCallback? endAnimation;
  final String reaction;

  const LiveReactionAnimation(
      {Key? key, this.endAnimation, required this.reaction})
      : super(key: key);

  @override
  _LiveReactionAnimationState createState() => _LiveReactionAnimationState();
}

class _LiveReactionAnimationState extends State<LiveReactionAnimation>
    with TickerProviderStateMixin {
  late AnimationController _controller;
  late Animation<double> _animationFloatUp;
  late Animation<double> _animationGrowSize;

  @override
  void initState() {
    super.initState();

    _controller = AnimationController(
        duration: const Duration(milliseconds: 1500), vsync: this);

    _controller.addStatusListener((status) {
      if (status == AnimationStatus.completed) {
        if (widget.endAnimation != null) {
          widget.endAnimation!();
        }
      }
    });
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();

    _animationFloatUp = Tween(begin: 0.0, end: 1.0).animate(
      CurvedAnimation(
        parent: _controller,
        curve: const Interval(0.0, 1, curve: Curves.easeIn),
      ),
    );

    _animationGrowSize = Tween(begin: 40.0, end: 200.0).animate(
      CurvedAnimation(
        parent: _controller,
        curve: const Interval(0.0, 1, curve: SineCurve()),
      ),
    );
    _controller.forward();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: _animationFloatUp,
      builder: (context, child) {
        return Opacity(
          opacity: (1 - _animationFloatUp.value),
          child: Container(
            child: child,
            margin: EdgeInsets.only(
              bottom: _animationFloatUp.value * 200,
              right: _animationGrowSize.value * 0.25,
            ),
            //width: _animationGrowSize.value,
          ),
        );
      },
      child: Image.asset(
        getImagePath(widget.reaction),
        package: UIConstants.packageName,
        color: Colors.red,
      ),
    );
  }

  String getImagePath(String icon) {
    switch (icon) {
      case "heart":
        return "assets/icons/heart.png";

      case "like":
        return "assets/icons/heart.png";

      case "dislike":
        return "assets/icons/heart.png";

      case "happy":
        return "assets/icons/heart.png";

      case "sad":
        return "assets/icons/heart.png";

      default:
        return "assets/icons/heart.png";
    }
  }
}

class LinerCurve extends Curve {
  final double count;

  const LinerCurve({this.count = 1});

  @override
  double transformInternal(double t) {
    var val = t;
    return val;
  }
}

class SineCurve extends Curve {
  final double count;

  const SineCurve({this.count = 2});

  @override
  double transformInternal(double t) {
    var val = sin(count * 2 * pi * t) * 0.5 + 0.5;
    return val;
  }
}
